package superpangworld;

import java.awt.*;

/**
 * The progress bar of a level.
 */
public class LevelProgressBar {

    /** The position of the progress bar */
    private Position position;
    /** The color of the progress bar */
    private final Color color;
    /** The size of the progress bar */
    private final double size;
    /** The width of the progress bar */
    private final double width;
    /** The height of the progress bar */
    private final double height;
    /** The GameView to display the progress bar*/
    private final GameView gameView;
    /** The progress of the level ranging from <code>0</code> to <code>100</code> */
    private int levelProgress;
    /** The top and bottom border of the progress bar */
    private final static String PROGRESS_BAR_BORDER = "WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW\n";

    /**
     * Create a progress bar with default values.
     * @param gameView the {@link GameView} to display the progress bar
     */
    public LevelProgressBar(GameView gameView){
        color = Color.BLUE;
        size = 3;
        width = size * 101;
        height = size * 8;
        levelProgress = 30;
        this.gameView = gameView;
        position = new Position(GameView.WIDTH/2 - (width/2),GameView.HEIGHT-height);
    }

    /**
     * Draws the level progress bar onto the canvas of the {@link GameView}.
     */
    public void addToCanvas(){
        String pixelArt = PROGRESS_BAR_BORDER;
        String progressBarMiddle = getProgressBarMiddle(levelProgress);
        pixelArt += progressBarMiddle.repeat(6);
        pixelArt += PROGRESS_BAR_BORDER;

        gameView.addBlockImageToCanvas(pixelArt, position.x, position.y,size, 0);
    }

    @Override
    public String toString() {
        return "Harpoon:" +position.toString();
    }

    /**
     * Set the progress of the level.
     * @param levelProgress the progress
     */
    public void setLevelProgress(int levelProgress){
        this.levelProgress = levelProgress;
    }

    /**
     * Create the middle part of the level progress bar
     * @param progress the progress to display
     * @return the pixel art representing the middle part of the progress bar
     */
    private String getProgressBarMiddle(int progress){
        String progressbarMiddle = "W";
        progressbarMiddle += "B".repeat(progress)+" ".repeat(100-progress);
        progressbarMiddle += "W\n";
        return progressbarMiddle;
    }
}
