package superpangworld;

import java.awt.*;

/**
 * The progress of a level.
 */
public class LevelProgress {

    private final static String HARPOON =
                    "    B    \n"+
                    "   BBB   \n"+
                    "  kkkkk \n"+
                    " k kkk k\n"+
                    " k kkk k\n";

    /** The position of the harpoon */
    private Position position;
    /** The speed of the harpune in pixel per tick */
    private final double speedInPixel;
    /** The color of the harpoon */
    private final Color color;
    /** The size of the harpoon */
    private final double size;
    /** The rotation of the harpoon */
    private final double rotation;
    /** The width of the harpoon */
    private final double width;
    /** The height of the harpoon */
    private final double height;
    /** The GameView to display the harpoon*/
    private final GameView gameView;

    /**
     * Create a harpoon with default values
     * @param gameView the {@link GameView} to display the bubble
     */
    public LevelProgress(GameView gameView){
        color = Color.BLUE;
        position = new Position(300,300);
        speedInPixel = 10;
        size = 3;
        width = size * 11;
        height = size * 11;
        rotation = 0;

        this.gameView = gameView;
    }

    /**
     * Zeichnet die Blase auf die {@link GameView}.
     */
    public void addToCanvas(){
        gameView.addBlockImageToCanvas(HARPOON, position.x, position.y,size, rotation);
    }

    @Override
    public String toString() {
        return "Harpoon:" +position.toString();
    }

    /**
     * Bewegt die Harpune einen Schritt weiter.
     */
    public void updatePosition(){
        position.up(speedInPixel);
    }
}
